pub fn parse_bus(s: &str, chars: BusBitChars) -> Option<BusName>Expand description
Parse a bus name. Returns None if s doesn’t contain bracket
notation; the caller should treat that as a scalar pin.
pub fn parse_bus(s: &str, chars: BusBitChars) -> Option<BusName>Parse a bus name. Returns None if s doesn’t contain bracket
notation; the caller should treat that as a scalar pin.